Learn R Programming

boggy (version 0.0.1)

boggy-package: boggy: Real-Time PCR Data Sets by Boggy et al. (2010)

Description

Real-time quantitative polymerase chain reaction (qPCR) data sets by Boggy et al. (2008) tools:::Rd_expr_doi("10.1371/journal.pone.0012355"). This package provides a dilution series for one PCR target: a random sequence that minimizes secondary structure and off-target primer binding. The data set is a six-point, ten-fold dilution series. For each concentration there are two replicates. Each amplification curve is 40 cycles long. Original raw data file: https://journals.plos.org/plosone/article/file?type=supplementary&id=10.1371/journal.pone.0012355.s004.

Arguments

Author

Maintainer: Ramiro Magno rmagno@pattern.institute (ORCID)

Other contributors:

  • Pattern Institute [copyright holder, funder]

See Also