The qPCR data set named s1 comprises a six-point, ten-fold dilution series, replicated in duplicates targeting an amplicon designed with a random sequence that minimizes secondary structure and off-target primer binding. Please read the Quantitative PCR data section, qPCR assays subsection of Boggy et al. (2010) for more details.
A tibble with 480 rows and 10 variables:
platePlate identifier. For this data set it is always missing
(NA).
wellWell identifier.
dyeThe type of dye used. In this data set the values are always
"SYTO 13", meaning 2 mM of the dsDNA dye SYTO-13 (Invitrogen, Carlsbad, CA).
targetTarget identifier: the amplicon used, a random sequence
dubbed "S1" by the original authors.
sample_typeSample type (all curves are standards, i.e. "std").
replicateReplicate identifier: either 1 or 2.
copiesStandard copy number.
dilutionDilution factor. Higher number means greater dilution.
cyclePCR cycle.
fluorRaw fluorescence values.